@echo off

rem oraError()
rem run()

rem
rem check ORACLE_HOME
rem
if "%ORACLE_HOME%" == "" goto ORA_ERROR

rem
rem get input parameters
rem
set SYS_USERNAME=%1
set SYS_PASSWORD=%2
set CONNECT_IDENTIFIER=%3

rem
rem input parameters %1, %2 and %3 are necessary
rem
if not "%SYS_USERNAME%" == "" if not "%SYS_PASSWORD%" == "" if not "%CONNECT_IDENTIFIER%" == ""  goto RUN

rem
rem set default input
rem
set SYS_USERNAME=sys
set SYS_PASSWORD=intershop
set CONNECT_IDENTIFIER=//localhost:1521/XE

echo.
echo The %0 script configure existing database instances
echo running as Oracle Express (XE), Standard / One (SE) or Enterprise Edition (EE)
echo to allow the Intershop application server to store all persistent data.
echo.
echo Requirements for the existing database instance are:
echo.
echo  * created with CHARACTER SET = AL32UTF8
echo  * installed Text component (user ctxsys)   ORACLE_HOME/ctx/admin/catctx.sql
echo    and language-specific default preference ORACLE_HOME/ctx/admin/defaults/dr0defin.sql
echo.
echo Usage: %0 [^<sys_username^> ^<sys_password^> ^<connect_identifier^>]
echo.
echo   sys_username:       the database sys user
echo   sys_password:       the database sys password
echo   connect_identifier: the connect_identifier can be in the form of
echo                       Net Service Name or Easy Connect.
echo                       [^<net_service_name^> ^| [//]host[:port]/^<service_name^>]
echo.
echo   Specify the database account sys username, sys password and connect identifier
echo   for the database connection.
echo.
echo   The ^<service_name^> is configured with the database instance
echo   and can be detected by querying the running instance with
echo.
echo     SHOW PARAMETER service_names or
echo     SELECT value FROM v$parameter WHERE name = 'service_names';
echo.
echo   Examples:
echo.
echo     localhost XE database server, service name = 'XE'
echo       %0 or
echo       %0 %SYS_USERNAME% %SYS_PASSWORD% //localhost:1521/XE
echo.
echo     remote XE database server, service name = 'XE'
echo       %0 %SYS_USERNAME% %SYS_PASSWORD% //remote_host:1521/XE
echo.
echo     remote SE/EE database server, service name = 'isdb.world'
echo       %0 %SYS_USERNAME% %SYS_PASSWORD% //remote_host:1521/isdb.world
echo.
echo   Notes:
echo.
echo   * SQL*Plus version 11g is required to connect
echo     via easy connect like //Host:Port/^<service_name^>
echo     Check with sqlplus -v
echo.
echo   * Connection errors (ORA-12154, ORA-12638):
echo     ORA-12154: TNS:could not resolve the connect identifier specified
echo     ORA-12638: Credential retrieval failed
echo.
echo     can be resolved by the following settings:
echo.
echo     NAMES.DIRECTORY_PATH=(TNSNAMES,EZCONNECT) within TNS_ADMIN\tnsnames.ora
echo     SQLNET.AUTHENTICATION_SERVICES=(NONE)     within TNS_ADMIN\sqlnet.ora
echo.
echo No sys user with password and no connect identifier was given.
echo Continue with the following defaults?
echo.
echo   sys_username:       %SYS_USERNAME%
echo   sys_password:       %SYS_PASSWORD%
echo   connect_identifier: %CONNECT_IDENTIFIER%
echo.
echo   %0 %SYS_USERNAME% %SYS_PASSWORD% %CONNECT_IDENTIFIER%
echo.
echo Press any key to continue or CTRL+C to stop this script.
echo.

pause

:RUN
set SQL_PLUS=%ORACLE_HOME%/bin/sqlplus.exe /nolog
echo.
echo Starting . . .
echo.
echo %SQL_PLUS% @../scripts/dbsetup.sql %SYS_USERNAME% %SYS_PASSWORD% %CONNECT_IDENTIFIER%
     %SQL_PLUS% @../scripts/dbsetup.sql %SYS_USERNAME% %SYS_PASSWORD% %CONNECT_IDENTIFIER%
echo.

goto EOF

:ORA_ERROR
echo.
echo Error: Found empty environment variable ORACLE_HOME!
echo.
echo Examples:
echo.
echo   1. 11g Oracle XE home
echo   set ORACLE_HOME=c:\oraclexe\app\oracle\product\11.2.0\server
echo.
echo   2. Other 11g Oracle home
echo   set ORACLE_HOME=c:\oracle\client
echo.

:EOF
